cmoncrawl.aggregator.utils.ndjson\_decoder.Decoder.\_\_init\_\_
===============================================================

.. currentmodule:: cmoncrawl.aggregator.utils.ndjson_decoder

.. automethod:: Decoder.__init__